summaryrefslogtreecommitdiffstats
path: root/ash/wm/property_util.h
diff options
context:
space:
mode:
authoroshima@chromium.org <oshima@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-07-18 16:40:06 +0000
committeroshima@chromium.org <oshima@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-07-18 16:40:06 +0000
commit8d625fbd16a1d20f5e34bd01b83b0402bd3b4c80 (patch)
tree4fd429027e6fe44e79e8395ae63d6542d7edf657 /ash/wm/property_util.h
parent87cc09add3a1a9ef94aaec1865fc3aaa23720aaa (diff)
downloadchromium_src-8d625fbd16a1d20f5e34bd01b83b0402bd3b4c80.zip
chromium_src-8d625fbd16a1d20f5e34bd01b83b0402bd3b4c80.tar.gz
chromium_src-8d625fbd16a1d20f5e34bd01b83b0402bd3b4c80.tar.bz2
* Use Virtual Screen Coordinates in more places
- When setting widget bounds. - Workspace Manager - When resizing - Restore bounds * Refactored ScreenPositionClient to manage Screen coordinates for different configurations. * Renamed GetBounds/SetBounds methods to GetScreen/ParentBounds to make it clear that in which coordinates you're dealing with. * I used InScreen/InParent for RestoreBounds because RestoreParent/ScreenBounds sounds strange. Converted Linux/Aura to use ScreenPositionClient. BUG=123160 TEST=several tests are updated to match VSC. added screen_ash_unittests. I'll update rest of tests when this is enable by default. Review URL: https://chromiumcodereview.appspot.com/10696023 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@147250 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/wm/property_util.h')
-rw-r--r--ash/wm/property_util.h22
1 files changed, 15 insertions, 7 deletions
diff --git a/ash/wm/property_util.h b/ash/wm/property_util.h
index 029880a..75adf0a 100644
--- a/ash/wm/property_util.h
+++ b/ash/wm/property_util.h
@@ -21,18 +21,26 @@ namespace internal {
class RootWindowController;
}
-// Sets the restore bounds property on |window|. Deletes existing bounds value
-// if exists.
-ASH_EXPORT void SetRestoreBounds(aura::Window* window, const gfx::Rect& bounds);
+// Sets the restore bounds property on |window| in the virtual screen
+// coordinates. Deletes existing bounds value if exists.
+ASH_EXPORT void SetRestoreBoundsInScreen(aura::Window* window,
+ const gfx::Rect& screen_bounds);
+// Same as |SetRestoreBoundsInScreen| except that the bounds is in the
+// parent's coordinates.
+ASH_EXPORT void SetRestoreBoundsInParent(aura::Window* window,
+ const gfx::Rect& parent_bounds);
// Same as SetRestoreBounds(), but does nothing if the restore bounds have
// already been set. The bounds used are the bounds of the window.
ASH_EXPORT void SetRestoreBoundsIfNotSet(aura::Window* window);
-// Returns the restore bounds property on |window|. NULL if the
-// restore bounds property does not exist for |window|. |window|
-// owns the bounds object.
-ASH_EXPORT const gfx::Rect* GetRestoreBounds(aura::Window* window);
+// Returns the restore bounds property on |window| in the virtual screen
+// coordinates. The bounds can be NULL if the bounds property does not
+// exist for |window|. |window| owns the bounds object.
+ASH_EXPORT const gfx::Rect* GetRestoreBoundsInScreen(aura::Window* window);
+// Same as |GetRestoreBoundsInScreen| except that it returns the
+// bounds in the parent's coordinates.
+ASH_EXPORT gfx::Rect GetRestoreBoundsInParent(aura::Window* window);
// Deletes and clears the restore bounds property on |window|.
ASH_EXPORT void ClearRestoreBounds(aura::Window* window);